@@ -208,14 +208,14 @@ def _datatables_repr_(df=None, tableId=None, **kwargs):
     return to_html_datatable(df, tableId, connected=_CONNECTED, **kwargs)
 
 
-def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
+def to_html_datatable(df=None, caption=None, tableId=None, connected=True, **kwargs):
     """Return the HTML representation of the given dataframe as an interactive datatable"""
     # Default options
     for option in dir(opt):
         if (
             option not in kwargs
             and not option.startswith("__")
-            and option != "read_package_file"
+            and option not in ["read_package_file", "warn_on_unexpected_types"]
         ):
             kwargs[option] = getattr(opt, option)
 
@@ -225,6 +225,11 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     css = kwargs.pop("css")
     tags = kwargs.pop("tags")
 
+    if caption is not None:
+        tags = '{}<caption style="white-space: nowrap; overflow: hidden">{}</caption>'.format(
+            tags, caption
+        )
+
     showIndex = kwargs.pop("showIndex")
     maxBytes = kwargs.pop("maxBytes", 0)
     maxRows = kwargs.pop("maxRows", 0)
@@ -281,20 +286,6 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     if not showIndex:
         df = df.set_index(pd.RangeIndex(len(df.index)))
 
-    # Unless an 'order' parameter is given, we preserve the current order of rows #99
-    order = kwargs.pop("order", None)
-
-    if order is None:
-        order = []
-
-        if showIndex:
-            if df.index.is_monotonic_increasing:
-                order = [[i, "asc"] for i, _ in enumerate(df.index.names)]
-            elif df.index.is_monotonic_decreasing:
-                order = [[i, "desc"] for i, _ in enumerate(df.index.names)]
-
-    kwargs["order"] = order
-
     table_header = _table_header(
         df, tableId, showIndex, classes, style, tags, footer, column_filters
     )
@@ -346,7 +337,11 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     )
 
     # Export the table data to JSON and include this in the HTML
-    dt_data = datatables_rows(df.reset_index() if showIndex else df)
+    if showIndex:
+        df = safe_reset_index(df)
+
+    dt_data = datatables_rows(df)
+
     output = replace_value(
         output, "const data = [];", "const data = {};".format(dt_data)
     )
@@ -354,7 +349,28 @@ def to_html_datatable(df=None, tableId=None, connected=True, **kwargs):
     return output
 
 
-def show(df=None, **kwargs):
+def safe_reset_index(df):
+    try:
+        return df.reset_index()
+    except ValueError:
+        # Issue #134: the above might fail if the index has duplicated names or if one of the
+        # index names is already a column, with e.g "ValueError: cannot insert A, already exists"
+        index_levels = [
+            pd.Series(
+                df.index.get_level_values(i),
+                name=name
+                or (
+                    "index{}".format(i)
+                    if isinstance(df.index, pd.MultiIndex)
+                    else "index"
+                ),
+            )
+            for i, name in enumerate(df.index.names)
+        ]
+        return pd.concat(index_levels + [df.reset_index(drop=True)], axis=1)
+
+
+def show(df=None, caption=None, **kwargs):
     """Show a dataframe"""
-    html = to_html_datatable(df, connected=_CONNECTED, **kwargs)
+    html = to_html_datatable(df, caption=caption, connected=_CONNECTED, **kwargs)
     display(HTML(html))
